# CrossTalk PM

CrossTalk PM serves as a digital intermediary, facilitating connections and communications between users from distinct online platforms. It primarily focuses on identifying mentions of Reddit usernames in external platforms like rDrama and subsequently, notifying the mentioned Reddit users. This endeavor aims to foster a seamless information exchange and enhance inter-community interactions.

## Key Features

- **User Mention Monitoring:** CrossTalk PM diligently scans specified platforms for Reddit usernames being mentioned, ensuring no significant mention goes unnoticed.
- **Automated User Notifications:** Upon detecting a mention, it autonomously initiates a Reddit chatroom or dispatches a private message to the mentioned user, thereby alerting them.
- **Adherence to Privacy:** The application is designed with a strong commitment to privacy, processing only publicly disclosed information and adhering to privacy norms.

## Getting Started

Below you'll find everything you need to know to get CrossTalk PM up and running.

### Prerequisites

Ensure you have the following installed:
- Node.js (version 14 or later is recommended for optimal compatibility)
- Redis server (for caching and message queuing functionalities)
- Drama Harvester https://fsdfsd.net/J/DramaHarvester

### Installation Steps

1. **Clone the Project:**
   ```bash
   git clone https://fsdfsd.net/J/CrossTalkPM.git
   ```
2. **Navigate to the Project Directory:**
   ```bash
   cd CrossTalkPM
   ```
3. **Install Dependencies:**
   ```bash
   npm install
   ```
4. **Set Up Environment Variables:** Create a `.env` file in the root of your project directory and populate it with the necessary configuration as shown below:
   ```env
   REDIS_HOST=127.0.0.1
   REDIS_PORT=6379
   # REDIS_PASSWORD=optional (uncomment if applicable)
   RDRAMA_API_KEY=your_rdrama_api_key_here
   redditClientId=your_reddit_client_id
   redditSecret=your_reddit_secret
   redditUsername=your_reddit_username
   redditPassword=your_reddit_password
   EXCLUDE_EMPLOYEES=True
   EXCLUDE_MODS=True
   KARMA_THRESHOLD=100000
   NOTIFICATION_COOLDOWN_HOURS=1
   ```

### Running CrossTalk PM

To activate CrossTalk PM, execute the following command within the project's root directory:
```bash
npm start
```
Upon launch, CrossTalk PM will commence its operation, scanning for user mentions and facilitating notifications through Redis.

## Contributing

We highly value and appreciate contributions from our community. Whether it's through submitting bug reports, requesting new features, or contributing directly to the codebase, your involvement is encouraged.

### How to Contribute:

1. Fork the repository.
2. Create your feature branch (`git checkout -b feature/YourFeature`).
3. Commit your changes (`git commit -am 'Add YourFeature'`).
4. Push to the branch (`git push origin feature/YourFeature`).
5. Create a new Pull Request.

## License

CrossTalk PM is made available under the MIT License.

